aboutsummaryrefslogtreecommitdiffhomepage
path: root/tensorflow/tools/dist_test
diff options
context:
space:
mode:
authorGravatar Amit Patankar <amitpatankar@google.com>2018-01-30 15:07:03 -0800
committerGravatar TensorFlower Gardener <gardener@tensorflow.org>2018-01-30 15:15:47 -0800
commitac7167794f7c22d42c14a8d2f47b9533e118d73f (patch)
treed396999497f20cf1392719d817bb1406ae9f51ca /tensorflow/tools/dist_test
parentb0ac7c553db40d42e699baa86442289b1314a2e1 (diff)
Supporting paths for build_server script.
PiperOrigin-RevId: 183899675
Diffstat (limited to 'tensorflow/tools/dist_test')
-rwxr-xr-xtensorflow/tools/dist_test/build_server.sh21
1 files changed, 14 insertions, 7 deletions
diff --git a/tensorflow/tools/dist_test/build_server.sh b/tensorflow/tools/dist_test/build_server.sh
index 878fabd248..225c034741 100755
--- a/tensorflow/tools/dist_test/build_server.sh
+++ b/tensorflow/tools/dist_test/build_server.sh
@@ -16,14 +16,15 @@
#
# Builds the test server for distributed (GRPC) TensorFlow
#
-# Usage: build_server.sh <docker_image_name> <whl_url> [--test]
+# Usage: build_server.sh <docker_image_name> <whl_file_location> [--test]
#
# Arguments:
# docker_image_name: Name of the docker image to build.
# E.g.: tensorflow/tf_grpc_test_server:0.11.0rc1
#
# whl_url: URL from which the TensorFlow whl file will be downloaded.
# E.g.: https://ci.tensorflow.org/view/Nightly/job/nightly-matrix-cpu/TF_BUILD_IS_OPT=OPT,TF_BUILD_IS_PIP=PIP,TF_BUILD_PYTHON_VERSION=PYTHON2,label=cpu-slave/lastSuccessfulBuild/artifact/pip_test/whl/tensorflow-0.11.0rc1-cp27-none-linux_x86_64.whl
+# E.g.: /path/to/folder/tensorflow-0.11.0rc1-cp27-none-linux_x86_64.whl
#
# The optional flag --test lets the script to use the Dockerfile for the
# testing GRPC server. Without the flag, the script will build the non-test
@@ -41,11 +42,11 @@ die() {
# Check arguments
if [[ $# -lt 2 ]]; then
- die "Usage: $0 <docker_image_name> <whl_url> [--test]"
+ die "Usage: $0 <docker_image_name> <whl_location> [--test]"
fi
DOCKER_IMG_NAME=$1
-WHL_URL=$2
+WHL_FILE_LOCATION=$2
shift 2
# Current script directory
@@ -53,7 +54,7 @@ DIR="$(cd "$(dirname "${BASH_SOURCE[0]}")" && pwd)"
BUILD_DIR=$(mktemp -d)
echo ""
-echo "Using whl file URL: ${WHL_URL}"
+echo "Using whl file URL: ${WHL_FILE_LOCATION}"
echo "Building in temporary directory: ${BUILD_DIR}"
cp -r ${DIR}/* "${BUILD_DIR}"/ || \
@@ -65,9 +66,15 @@ if [[ $1 == "--test" ]]; then
fi
echo "Using Docker file: ${DOCKER_FILE}"
+if [[ $WHL_FILE_LOCATION =~ 'http://' || $WHL_FILE_LOCATION =~ 'https://' ]]; then
+ # Download whl file into the build context directory.
+ wget -P "${BUILD_DIR}" "${WHL_FILE_LOCATION}" || \
+ die "Failed to download tensorflow whl file from URL: ${WHL_FILE_LOCATION}"
+else
+ cp "${WHL_FILE_LOCATION}" "${BUILD_DIR}"
+fi
+
# Download whl file into the build context directory.
-wget -P "${BUILD_DIR}" ${WHL_URL} || \
- die "Failed to download tensorflow whl file from URL: ${WHL_URL}"
if [[ ! -f "${DOCKER_FILE}" ]]; then
die "ERROR: Unable to find dockerfile: ${DOCKER_FILE}"
@@ -16,14 +16,15 @@
# E.g.: tensorflow/tf_grpc_test_server:0.11.0rc1
#
-# whl_url: URL from which the TensorFlow whl file will be downloaded.
+# whl_file_location: URL from which the TensorFlow whl file will be downloaded.
# E.g.: https://ci.tensorflow.org/view/Nightly/job/nightly-matrix-cpu/TF_BUILD_IS_OPT=OPT,TF_BUILD_IS_PIP=PIP,TF_BUILD_PYTHON_VERSION=PYTHON2,label=cpu-slave/lastSuccessfulBuild/artifact/pip_test/whl/tensorflow-0.11.0rc1-cp27-none-linux_x86_64.whl